@@ -15,8 +15,8 @@ Copy the "docs" directory to the pyzo root!
 
 """
 
+import pyzo
 from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
-from pyzo import getResourceDirs
 import os
 
 
@@ -72,10 +72,14 @@ class Settings(QtWidgets.QWidget):
         del_button.clicked.connect(self.del_doc)
 
     def add_doc(self):
+        options = QtWidgets.QFileDialog.Option(0)
+        if not pyzo.config.advanced.useNativeFileDialogs:
+            options |= QtWidgets.QFileDialog.Option.DontUseNativeDialog
         doc_file = QtWidgets.QFileDialog.getOpenFileName(
             self,
             "Select a compressed help file",
             filter="Qt compressed help files (*.qch)",
+            options=options,
         )
         if isinstance(doc_file, tuple):
             doc_file = doc_file[0]
@@ -139,10 +143,9 @@ class PyzoAssistant(QtWidgets.QWidget):
 
         super().__init__(parent)
         self.setWindowTitle("Help")
-        pyzoDir, appDataDir, appConfigDir = getResourceDirs()
         if collection_filename is None:
             # Collection file is stored in pyzo data dir:
-            collection_filename = os.path.join(appDataDir, "tools", "docs.qhc")
+            collection_filename = os.path.join(pyzo.appDataDir, "tools", "docs.qhc")
         self._engine = QtHelp.QHelpEngine(collection_filename)
 
         # Important, call setup data to load the files:
@@ -150,7 +153,7 @@ class PyzoAssistant(QtWidgets.QWidget):
 
         # If no files are loaded, register at least the pyzo docs:
         if len(self._engine.registeredDocumentations()) == 0:
-            doc_file = os.path.join(pyzoDir, "resources", "pyzo.qch")
+            doc_file = os.path.join(pyzo.pyzoDir, "resources", "pyzo.qch")
             self._engine.registerDocumentation(doc_file)
 
         # The main players:
