@@ -39,7 +39,7 @@ from pyzo.core.menu import ShellContextMenu
 
 # Interval for polling messages. Timer for each kernel. I found
 # that this one does not affect performance much
-POLL_TIMER_INTERVAL = 30  # 30 ms 33Hz
+POLL_TIMER_INTERVAL = 100  # 100ms 10Hz
 
 # Maximum number of lines in the shell
 MAXBLOCKCOUNT = pyzo.config.advanced.shellMaxLines
@@ -114,7 +114,6 @@ class ShellHighlighter(Highlighter):
     """
 
     def highlightBlock(self, line):
-
         # Make sure this is a Unicode Python string
         line = str(line)
 
@@ -360,19 +359,20 @@ class BaseShell(BaseTextCtrl):
         after = line[pos:].split('"')[0]
         piece = before + after
 
-        # Check if it looks like a filename, quit if it does not
-        if len(piece) < 4:
-            return
-        elif not ("/" in piece or "\\" in piece):
-            return
-        #
-        if sys.platform.startswith("win"):
-            if piece[1] != ":":
+        if not re.fullmatch(r"<tmp \d+>", piece):
+            # Check if it looks like a filename, quit if it does not
+            if len(piece) < 4:
                 return
-        else:
-            if not piece.startswith("/"):
+            elif not ("/" in piece or "\\" in piece):
                 return
-        #
+
+            if sys.platform.startswith("win"):
+                if piece[1] != ":":
+                    return
+            else:
+                if not piece.startswith("/"):
+                    return
+
         filename = piece
 
         # Split in parts for getting line number
@@ -448,9 +448,7 @@ class BaseShell(BaseTextCtrl):
 
     ## Key handlers
     def keyPressEvent(self, event):
-
         if event.key() in [Qt.Key_Return, Qt.Key_Enter]:
-
             # First check if autocompletion triggered
             if self.potentiallyAutoComplete(event):
                 return
@@ -497,7 +495,6 @@ class BaseShell(BaseTextCtrl):
                 return  # Ignore the key, don't go beyond the prompt
 
         if event.key() in [Qt.Key_Up, Qt.Key_Down] and not self.autocompleteActive():
-
             # needle
             if self._historyNeedle is None:
                 # get partly-written-command
@@ -631,7 +628,6 @@ class BaseShell(BaseTextCtrl):
         self.ensureCursorVisible()
 
     def _handleBackspaces_split(self, text):
-
         # while NOT a backspace at first position, or none found
         i = 9999999999999
         while i > 0:
@@ -659,7 +655,6 @@ class BaseShell(BaseTextCtrl):
         N = 0
 
         for i in range(len(texts)):
-
             # Remove backspaces in text and how many are left
             n, text = self._handleBackspaces_split(texts[i])
             texts[i] = text
@@ -871,7 +866,6 @@ class BaseShell(BaseTextCtrl):
         i0 = 0
 
         for match in re.finditer(pattern, text):
-
             # Insert pending text with the current format
             # Also update indices
             i1, i2 = match.span()
