@@ -35,7 +35,7 @@ import traceback
 import keyword
 import inspect  # noqa - Must be in this namespace
 import bdb
-from distutils.version import LooseVersion as LV
+import linecache
 
 import yoton
 from pyzokernel import guiintegration, printDirect
@@ -353,10 +353,23 @@ class PyzoInterpreter:
 
         # Prevent app nap on OSX 9.2 and up
         # The _nope module is taken from MINRK's appnope package
-        if sys.platform == "darwin" and LV(platform.mac_ver()[0]) >= LV("10.9"):
-            from pyzokernel import _nope
+        if sys.platform == "darwin":
 
-            _nope.nope()
+            def parse_version_crudely(version_string):
+                """extracts the leading number parts of a version string to a tuple
+                e.g.: "123.45ew6.7x.dev8" --> (123, 45, 7)
+                """
+                import re
+
+                return tuple(
+                    int(s) for s in re.findall(r"\.(\d+)", "." + version_string)
+                )
+
+            parsev = parse_version_crudely
+            if parsev(platform.mac_ver()[0]) >= parsev("10.9"):
+                from pyzokernel import _nope
+
+                _nope.nope()
 
         # Setup post-mortem debugging via appropriately logged exceptions
         class PMHandler(logging.Handler):
@@ -632,7 +645,7 @@ class PyzoInterpreter:
         if self._codeToRunOnStartup:
             self.context._stat_interpreter.send("Busy")
             self._codeToRunOnStartup, tmp = None, self._codeToRunOnStartup
-            self.pushline(tmp)
+            self._runlines(tmp, filename="<startup_after_gui>", symbol="exec")
         if self._scriptToRunOnStartup:
             self.context._stat_interpreter.send("Busy")
             self._scriptToRunOnStartup, tmp = None, self._scriptToRunOnStartup
@@ -1227,22 +1240,22 @@ class ExecutedSourceCollection:
 
     def _patch(self):
         def getlines(filename, module_globals=None):
+            # !!! do not use "import" inside this function because it can
+            # cause an infinite recursion loop with the import override in
+            # module shiboken6 (PySide6) !!!
+
             # Try getting the source from our own cache,
             # otherwise fallback to linecache's own cache
             src = self._cache.get(filename, "")
             if src:
                 return [line + "\n" for line in src.splitlines()]
             else:
-                import linecache
-
                 if module_globals is None:
                     return linecache._getlines(filename)  # only valid sig in 2.4
                 else:
                     return linecache._getlines(filename, module_globals)
 
         # Monkey patch
-        import linecache
-
         linecache._getlines = linecache.getlines
         linecache.getlines = getlines
 
