@@ -40,18 +40,27 @@ The config consists of three fields:
   * Support for multiple browsers.
 """
 
+import sys
 import os.path as op
 
 import pyzo
 from pyzo.util import zon as ssdf
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets, API, PYSIDE_VERSION  # noqa
 
 from .browser import Browser
 from .utils import cleanpath, isdir
 
 
+def _check_qt_version():
+    if sys.platform == "darwin":
+        if API == "pyside6" and PYSIDE_VERSION > "6.5.0":
+            print(
+                "\nWARNING:On MacOS The file browser may be unstable with PySide6 version 6.5.1+ and up.\n"
+            )
+
+
 class PyzoFileBrowser(QtWidgets.QWidget):
-    """ The main tool widget. An instance of this class contains one or
+    """The main tool widget. An instance of this class contains one or
     more Browser instances. If there are more, they can be selected
     using a tab bar.
     """
@@ -59,6 +68,8 @@ class PyzoFileBrowser(QtWidgets.QWidget):
     def __init__(self, parent):
         QtWidgets.QWidget.__init__(self, parent)
 
+        _check_qt_version()
+
         # Get config
         toolId = self.__class__.__name__.lower() + "2"  # This is v2 of the file browser
         if toolId not in pyzo.config.tools:
@@ -108,14 +119,12 @@ class PyzoFileBrowser(QtWidgets.QWidget):
         layout.setContentsMargins(margin, margin, margin, margin)
 
     def path(self):
-        """ Get the current path shown by the file browser.
-        """
+        """Get the current path shown by the file browser."""
         browser = self._browsers[0]
         return browser._tree.path()
 
     def setPath(self, path):
-        """ Set the shown path.
-        """
+        """Set the shown path."""
         browser = self._browsers[0]
         browser._tree.setPath(path)
 
@@ -147,7 +156,10 @@ class PyzoFileBrowser(QtWidgets.QWidget):
             return path
 
     def closeEvent(self, event):
+        self.cleanUp()
+        return QtWidgets.QWidget.closeEvent(self, event)
+
+    def cleanUp(self):
         # Close all browsers so they can clean up the file system proxies
         for browser in self._browsers:
-            browser.close()
-        return QtWidgets.QWidget.closeEvent(self, event)
+            browser.cleanUp()
