@@ -15,7 +15,6 @@ class SearchTask(proxies.Task):
     __slots__ = []
 
     def process(self, proxy, pattern=None, matchCase=False, regExp=False, **rest):
-
         # Quick test
         if not pattern:
             return
@@ -44,7 +43,6 @@ class SearchTask(proxies.Task):
             return []
 
     def _getText(self, proxy):
-
         # Init
         path = proxy.path()
         fsProxy = proxy._fsProxy
@@ -100,7 +98,6 @@ class SearchTask(proxies.Task):
         return indices
 
     def _indicesToLines(self, text, indices):
-
         # Determine line endings
         LE = self._determineLineEnding(text)
 
@@ -122,7 +119,7 @@ class SearchTask(proxies.Task):
         return lines
 
     def _determineLineEnding(self, text):
-        """ function to determine quickly whether LF or CR is used
+        """function to determine quickly whether LF or CR is used
         as line endings. Windows endings (CRLF) result in LF
         (you can split lines with either char).
         """
@@ -140,8 +137,7 @@ class SearchTask(proxies.Task):
 
 
 class PeekTask(proxies.Task):
-    """ To peek the high level structure of a task.
-    """
+    """To peek the high level structure of a task."""
 
     __slots__ = []
 
@@ -178,7 +174,6 @@ class PeekTask(proxies.Task):
         return list(self._parseLines(text.splitlines()))
 
     def _parseLines(self, lines):
-
         stringEndProg = None
 
         linenr = 0
