@@ -20,7 +20,7 @@ from yoton.channels import BaseChannel, OBJECT
 
 
 # For the req/rep channels to negotiate (simple load balancing)
-REQREP_SEQ_REF = 2 ** 63
+REQREP_SEQ_REF = 2**63
 
 # Define object to recognize errors
 ERROR_OBJECT = "yoton_ERROR_HANDLING_REQUEST"
@@ -44,21 +44,20 @@ class CancelledError(Exception):
 
 
 class Future(object):
-    """ Future(req_channel, req, request_id)
-    
+    """Future(req_channel, req, request_id)
+
     The Future object represents the future result of a request done at
     a yoton.ReqChannel.
-    
+
     It enables:
       * checking whether the request is done.
       * getting the result or the exception raised during handling the request.
       * canceling the request (if it is not yet running)
       * registering callbacks to handle the result when it is available
-    
+
     """
 
     def __init__(self, req_channel, req, request_id):
-
         # For being a Future object
         self._result = None
         self._status = 0  # 0:waiting, 1:running, 2:canceled, 3:error, 4:success
@@ -77,10 +76,10 @@ class Future(object):
         self._auto_cancel_timeout = 10.0
 
     def _send(self, msg):
-        """ _send(msg)
-        
+        """_send(msg)
+
         For sending pre-request messages 'req?', 'req-'.
-        
+
         """
         msg = msg.encode("utf-8")
         try:
@@ -91,13 +90,13 @@ class Future(object):
             self.cancel()
 
     def _resend_if_necessary(self):
-        """ _resend_if_necessary()
-        
+        """_resend_if_necessary()
+
         Resends the pre-request message if we have not done so for the last
         0.5 second.
-        
+
         This will also auto-cancel the message if it is resend over 20 times.
-        
+
         """
         timetime = time.time()
         if self._status != 0:
@@ -109,13 +108,13 @@ class Future(object):
             self._next_send_time = timetime + 0.5
 
     def set_auto_cancel_timeout(self, timeout):
-        """ set_auto_cancel_timeout(timeout):
-        
+        """set_auto_cancel_timeout(timeout):
+
         Set the timeout after which the call is automatically cancelled
         if it is not done yet. By default, this value is 10 seconds.
-        
+
         If timeout is None, there is no limit to the wait time.
-        
+
         """
         if timeout is None:
             timeout = 999999999999999999.0
@@ -125,12 +124,12 @@ class Future(object):
             raise ValueError("A timeout cannot be negative")
 
     def cancel(self):
-        """ cancel()
-        
+        """cancel()
+
         Attempt to cancel the call. If the call is currently being executed
         and cannot be cancelled then the method will return False, otherwise
         the call will be cancelled and the method will return True.
-        
+
         """
 
         if self._status == 1:
@@ -148,37 +147,37 @@ class Future(object):
             return True
 
     def cancelled(self):
-        """ cancelled()
-        
+        """cancelled()
+
         Return True if the call was successfully cancelled.
-        
+
         """
         return self._status == 2
 
     def running(self):
-        """ running()
-        
+        """running()
+
         Return True if the call is currently being executed and cannot be
         cancelled.
-        
+
         """
         return self._status == 1
 
     def done(self):
-        """ done()
-        
+        """done()
+
         Return True if the call was successfully cancelled or finished running.
-        
+
         """
         return self._status in [2, 3, 4]
 
     def _wait(self, timeout):
-        """ _wait(timeout)
-        
+        """_wait(timeout)
+
         Wait for the request to be handled for the specified amount of time.
         While waiting, the ReqChannel local event loop is called so that
         pre-request messages can be exchanged.
-        
+
         """
 
         # No timout means a veeeery long timeout
@@ -193,8 +192,8 @@ class Future(object):
             time.sleep(0.01)  # 10 ms
 
     def result(self, timeout=None):
-        """ result(timeout=None)
-        
+        """result(timeout=None)
+
         Return the value returned by the call. If the call hasn’t yet
         completed then this method will wait up to timeout seconds. If
         the call hasn’t completed in timeout seconds, then a TimeoutError
@@ -222,13 +221,13 @@ class Future(object):
             return self._result
 
     def result_or_cancel(self, timeout=1.0):
-        """ result_or_cancel(timeout=1.0)
-        
+        """result_or_cancel(timeout=1.0)
+
         Return the value returned by the call. If the call hasn’t yet
         completed then this method will wait up to timeout seconds. If
         the call hasn’t completed in timeout seconds, then the call is
         cancelled and the method will return None.
-        
+
         """
 
         # Wait
@@ -242,19 +241,19 @@ class Future(object):
             return None
 
     def exception(self, timeout=None):
-        """ exception(timeout)
-        
+        """exception(timeout)
+
         Return the exception raised by the call. If the call hasn’t yet
         completed then this method will wait up to timeout seconds. If
         the call hasn’t completed in timeout seconds, then a TimeoutError
         will be raised. timeout can be an int or float. If timeout is not
         specified or None, there is no limit to the wait time.
-        
+
         If the future is cancelled before completing then CancelledError
         will be raised.
-        
+
         If the call completed without raising, None is returned.
-        
+
         """
 
         # Wait
@@ -271,20 +270,20 @@ class Future(object):
             return None  # no exception
 
     def add_done_callback(self, fn):
-        """ add_done_callback(fn)
-        
+        """add_done_callback(fn)
+
         Attaches the callable fn to the future. fn will be called, with
         the future as its only argument, when the future is cancelled or
         finishes running.
-        
+
         Added callables are called in the order that they were added. If
         the callable raises a Exception subclass, it will be logged and
         ignored. If the callable raises a BaseException subclass, the
         behavior is undefined.
-        
+
         If the future has already completed or been cancelled, fn will be
         called immediately.
-        
+
         """
 
         # Check
@@ -298,21 +297,21 @@ class Future(object):
             self._callbacks.append(fn)
 
     def set_running_or_notify_cancel(self):
-        """ set_running_or_notify_cancel()
-        
+        """set_running_or_notify_cancel()
+
         This method should only be called by Executor implementations before
         executing the work associated with the Future and by unit tests.
-        
+
         If the method returns False then the Future was cancelled, i.e.
         Future.cancel() was called and returned True.
-        
+
         If the method returns True then the Future was not cancelled and
         has been put in the running state, i.e. calls to Future.running()
         will return True.
-        
+
         This method can only be called once and cannot be called after
         Future.set_result() or Future.set_exception() have been called.
-        
+
         """
 
         if self._status == 2:
@@ -326,12 +325,12 @@ class Future(object):
             )
 
     def set_result(self, result):
-        """ set_result(result)
-        
+        """set_result(result)
+
         Sets the result of the work associated with the Future to result.
         This method should only be used by Executor implementations and
         unit tests.
-        
+
         """
 
         # Set result if indeed in running state
@@ -342,12 +341,12 @@ class Future(object):
                 yoton.call_later(fn, 0, self)
 
     def set_exception(self, exception):
-        """ set_exception(exception)
-        
+        """set_exception(exception)
+
         Sets the result of the work associated with the Future to the
         Exception exception. This method should only be used by Executor
         implementations and unit tests.
-        
+
         """
 
         # Check
@@ -365,21 +364,21 @@ class Future(object):
 
 
 class ReqChannel(BaseChannel):
-    """ ReqChannel(context, slot_base)
-    
+    """ReqChannel(context, slot_base)
+
     The request part of the request/reply messaging pattern.
     A ReqChannel instance sends request and receive the corresponding
     replies. The requests are replied by a yoton.RepChannel instance.
-    
+
     This class adopts req/rep in a remote procedure call (RPC) scheme.
     The handling of the result is done using a yoton.Future object, which
     follows the approach specified in PEP 3148. Note that for the use
     of callbacks, the yoton event loop must run.
-    
+
     Basic load balancing is performed by first asking all potential
     repliers whether they can handle a request. The actual request
     is then send to the first replier to respond.
-    
+
     Parameters
     ----------
     context : yoton.Context instance
@@ -389,25 +388,25 @@ class ReqChannel(BaseChannel):
         message type and messaging pattern to create the final slot name.
         The final slot is used to connect channels at different contexts
         in a network
-    
+
     Usage
     -----
     One performs a call on a virtual method of this object. The actual
     method is executed by the yoton.RepChannel instance. The method can be
     called with normal and keyword arguments, which can be (a
     combination of): None, bool, int, float, string, list, tuple, dict.
-    
+
     Example
     -------
     # Fast, but process is idling when waiting for the response.
     reply = req.add(3,4).result(2.0) # Wait two seconds
-    
+
     # Asynchronous processing, but no waiting.
     def reply_handler(future):
         ... # Handle reply
     future = req.add(3,4)
     future.add_done_callback(reply_handler)
-    
+
     """
 
     # Notes on load balancing:
@@ -488,14 +487,14 @@ class ReqChannel(BaseChannel):
             return proxy_function
 
     def _handle_request(self, name, *args, **kwargs):
-        """ _handle_request(request, callback, **kwargs)
-        
+        """_handle_request(request, callback, **kwargs)
+
         Post a request. This creates a Future instance and stores
         it. A message is send asking any repliers to respond.
-        
+
         The actual request will be send when a reply to our pre-request
         is received. This all hapens in the yoton event loop.
-        
+
         """
 
         # Create request object
@@ -518,15 +517,15 @@ class ReqChannel(BaseChannel):
         return item
 
     def _resend_requests(self):
-        """ _resend_requests()
-        
+        """_resend_requests()
+
         See if we should resend our older requests. Periodically calling
         this method enables doing a request while the replier is not yet
         attached to the network.
-        
+
         This also allows the Future objects to cancel themselves if it
         takes too long.
-        
+
         """
         for request_id in [key for key in self._request_items.keys()]:
             item = self._request_items[request_id]
@@ -537,15 +536,15 @@ class ReqChannel(BaseChannel):
                 item._resend_if_necessary()
 
     def _recv_item(self):
-        """ _recv_item()
-        
+        """_recv_item()
+
         Receive item. If a reply is send that is an acknowledgement
         of a replier that it wants to handle our request, the
         correpsonding request is send to that replier.
-        
+
         This is a kind of mini-event loop thingy that should be
         called periodically to keep things going.
-        
+
         """
 
         # Receive package
@@ -597,10 +596,10 @@ class ReqChannel(BaseChannel):
                 return item
 
     def _process_events_local(self, dummy=None):
-        """ _process_events_local()
-        
+        """_process_events_local()
+
         Process events only for this object. Used by _handle_now().
-        
+
         """
 
         # Check periodically if we should resend (or clean up) old requests
@@ -624,22 +623,22 @@ class ReqChannel(BaseChannel):
 
 
 class RepChannel(BaseChannel):
-    """ RepChannel(context, slot_base)
-    
+    """RepChannel(context, slot_base)
+
     The reply part of the request/reply messaging pattern.
     A RepChannel instance receives request and sends the corresponding
     replies. The requests are send from a yoton.ReqChannel instance.
-    
+
     This class adopts req/rep in a remote procedure call (RPC) scheme.
-    
+
     To use a RepChannel, subclass this class and implement the methods
     that need to be available. The reply should be (a combination of)
     None, bool, int, float, string, list, tuple, dict.
-    
+
     This channel needs to be set to event or thread mode to function
     (in the first case yoton events need to be processed too).
     To stop handling events again, use set_mode('off').
-    
+
     Parameters
     ----------
     context : yoton.Context instance
@@ -649,7 +648,7 @@ class RepChannel(BaseChannel):
         message type and messaging pattern to create the final slot name.
         The final slot is used to connect channels at different contexts
         in a network
-    
+
     """
 
     def __init__(self, context, slot_base):
@@ -678,15 +677,15 @@ class RepChannel(BaseChannel):
     # Node that setters for normal and event_driven mode are specified in
     # channels_base.py
     def set_mode(self, mode):
-        """ set_mode(mode)
-        
+        """set_mode(mode)
+
         Set the replier to its operating mode, or turn it off.
-        
+
         Modes:
           * 0 or 'off': do not process requests
           * 1 or 'event': use the yoton event loop to process requests
           * 2 or 'thread': process requests in a separate thread
-        
+
         """
 
         if isinstance(mode, basestring):
@@ -700,18 +699,18 @@ class RepChannel(BaseChannel):
             self._timer.start()
         elif mode in [2, "thread", "thread-driven"]:
             self._run_mode = 2
-            if not self._thread.isAlive():
+            if not self._thread.is_alive():
                 self._thread.start()
         else:
             raise ValueError("Invalid mode for ReqChannel instance.")
 
     def _handle_request(self, message):
-        """ _handle_request(message)
-        
+        """_handle_request(message)
+
         This method is called for each request, and should return
         a reply. The message contains the name of the method to call,
         this function calls that method.
-        
+
         """
         # Get name and args
         name, args, kwargs = message
@@ -726,7 +725,6 @@ class RepChannel(BaseChannel):
         return func(*args, **kwargs)
 
     def _acknowledge_next_pre_request(self):
-
         # Cancel current pre-request ourselves if it takes too long.
         # Failsafe, only for if resetting by requester fails somehow.
         if time.time() - self._pre_request_time > 10.0:
@@ -734,7 +732,6 @@ class RepChannel(BaseChannel):
 
         # Send any pending pre requests
         if self._pre_requests and not self._pre_request:
-
             # Set current pre-request and its ack time
             package = self._pre_requests.pop(0)
             self._pre_request = package
@@ -750,10 +747,10 @@ class RepChannel(BaseChannel):
             # print 'ack', self._context.id,  package._dest_seq-REQREP_SEQ_REF
 
     def _replier_iteration(self, package):
-        """ _replier_iteration()
-        
+        """_replier_iteration()
+
         Do one iteration: process one request.
-        
+
         """
 
         # Get request id
@@ -820,10 +817,10 @@ class RepChannel(BaseChannel):
                     print(getErrorMsg())
 
     def _process_events_local(self, dummy=None):
-        """ _process_events_local()
-        
+        """_process_events_local()
+
         Called when a message (or more) has been received.
-        
+
         """
 
         # If closed, unregister from signal and stop the timer
@@ -843,21 +840,21 @@ class RepChannel(BaseChannel):
                 return
 
     def echo(self, arg1, sleep=0.0):
-        """ echo(arg1, sleep=0.0)
-        
+        """echo(arg1, sleep=0.0)
+
         Default procedure that can be used for testing. It returns
         a tuple (first_arg, context_id)
-        
+
         """
         time.sleep(sleep)
         return arg1, hex(self._context.id)
 
 
 class ThreadForReqChannel(threading.Thread):
-    """ ThreadForReqChannel(channel)
-    
+    """ThreadForReqChannel(channel)
+
     Thread to run a RepChannel in threaded mode.
-    
+
     """
 
     def __init__(self, channel):
@@ -874,10 +871,10 @@ class ThreadForReqChannel(threading.Thread):
         self.setDaemon(True)
 
     def run(self):
-        """ run()
-        
+        """run()
+
         The handler's main loop.
-        
+
         """
 
         # Get ref to channel. Remove ref from instance
@@ -885,7 +882,6 @@ class ThreadForReqChannel(threading.Thread):
         del self._channel
 
         while True:
-
             # Stop?
             if channel.closed or channel._run_mode != 2:
                 break
