@@ -29,20 +29,19 @@ from yoton.misc import Property, getErrorMsg, PackageQueue
 
 
 class CallableObject(object):
-    """ CallableObject(callable)
-    
+    """CallableObject(callable)
+
     A class to hold a callable. If it is a plain function, its reference
     is held (because it might be a closure). If it is a method, we keep
     the function name and a weak reference to the object. In this way,
     having for instance a signal bound to a method, the object is not
     prevented from being cleaned up.
-    
+
     """
 
     __slots__ = ["_ob", "_func"]  # Use __slots__ to reduce memory footprint
 
     def __init__(self, c):
-
         # Check
         if not hasattr(c, "__call__"):
             raise ValueError("Error: given callback is not callable.")
@@ -62,8 +61,7 @@ class CallableObject(object):
             self._ob = None
 
     def isdead(self):
-        """ Get whether the weak ref is dead.
-        """
+        """Get whether the weak ref is dead."""
         if self._ob:
             # Method
             return self._ob() is None
@@ -71,8 +69,7 @@ class CallableObject(object):
             return False
 
     def compare(self, other):
-        """ compare this instance with another.
-        """
+        """compare this instance with another."""
         if self._ob and other._ob:
             return (self._ob() is other._ob()) and (self._func == other._func)
         elif not (self._ob or other._ob):
@@ -84,7 +81,7 @@ class CallableObject(object):
         return self._func.__str__()
 
     def call(self, *args, **kwargs):
-        """ call(*args, **kwargs)
+        """call(*args, **kwargs)
         Call the callable. Exceptions are caught and printed.
         """
         if self.isdead():
@@ -108,13 +105,13 @@ class CallableObject(object):
 
 
 class Event(object):
-    """ Event(callable, *args, **kwargs)
-    
+    """Event(callable, *args, **kwargs)
+
     An Event instance represents something that is going to be done.
     It consists of a callable and arguments to call it with.
-    
+
     Instances of this class populate the event queue.
-    
+
     """
 
     __slots__ = ["_callable", "_args", "_kwargs", "_timeout"]
@@ -128,31 +125,30 @@ class Event(object):
         self._kwargs = kwargs
 
     def dispatch(self):
-        """ dispatch()
+        """dispatch()
         Call the callable with the arguments and keyword-arguments specified
         at initialization.
         """
         self._callable.call(*self._args, **self._kwargs)
 
     def _on_timeout(self):
-        """ This is what theTimerThread calls.
-        """
+        """This is what theTimerThread calls."""
         app.post_event(self)
 
 
 class Signal:
-    """ Signal()
-    
+    """Signal()
+
     The purpose of a signal is to provide an interface to bind/unbind
     to events and to fire them.
-    
+
     One can bind() or unbind() a callable to the signal. When emitted, an
     event is created for each bound handler. Therefore, the event loop
     must run for signals to work.
-    
+
     Some signals call the handlers using additional arguments to
     specify specific information.
-    
+
     """
 
     def __init__(self):
@@ -160,19 +156,18 @@ class Signal:
 
     @property
     def type(self):
-        """ The type (__class__) of this event.
-        """
+        """The type (__class__) of this event."""
         return self.__class__
 
     def bind(self, func):
-        """ bind(func)
-        
+        """bind(func)
+
         Add an eventhandler to this event.
-        
+
         The callback/handler (func) must be a callable. It is called
         with one argument: the event instance, which can contain
         additional information about the event.
-        
+
         """
 
         # make callable object (checks whether func is callable)
@@ -188,10 +183,10 @@ class Signal:
         self._handlers.append(cnew)
 
     def unbind(self, func=None):
-        """ unbind(func=None)
-        
+        """unbind(func=None)
+
         Unsubscribe a handler, If func is None, remove all handlers.
-        
+
         """
         if func is None:
             self._handlers[:] = []
@@ -203,12 +198,12 @@ class Signal:
                     self._handlers.remove(c)
 
     def emit(self, *args, **kwargs):
-        """ emit(*args, **kwargs)
-        
+        """emit(*args, **kwargs)
+
         Emit the signal, calling all bound callbacks with *args and **kwargs.
         An event is queues for each callback registered to this signal.
         Therefore it is safe to call this method from another thread.
-        
+
         """
 
         # Add an event for each callback
@@ -225,12 +220,12 @@ class Signal:
             self._handlers.remove(func)
 
     def emit_now(self, *args, **kwargs):
-        """ emit_now(*args, **kwargs)
-        
+        """emit_now(*args, **kwargs)
+
         Emit the signal *now*. All handlers are called from the calling
         thread. Beware, this should only be done from the same thread
         that runs the event loop.
-        
+
         """
 
         # Add an event for each callback
@@ -247,7 +242,7 @@ class Signal:
 
 
 class TheTimerThread(threading.Thread):
-    """ TheTimerThread is a singleton thread that is used by all timers
+    """TheTimerThread is a singleton thread that is used by all timers
     and delayed events to wait for a while (in a separate thread) and then
     post an event to the event-queue. By sharing a single thread timers
     stay lightweight and there is no time spend on initializing or tearing
@@ -274,7 +269,7 @@ class TheTimerThread(threading.Thread):
         self.join(timeout)
 
     def add(self, timer):
-        """ add(timer)
+        """add(timer)
         Add item to the list of objects to track. The object should
         have a _timeout attribute, representing the time.time() at which
         it runs out, and an _on_timeout() method to call when it does.
@@ -316,7 +311,6 @@ class TheTimerThread(threading.Thread):
 
     def _mainloop(self):
         while not self._exit:
-
             # Set flag
             self._somethingChanged = False
 
@@ -349,18 +343,18 @@ theTimerThread.start()
 
 
 class Timer(Signal):
-    """ Timer(interval=1.0, oneshot=True)
-    
+    """Timer(interval=1.0, oneshot=True)
+
     Timer class. You can bind callbacks to the timer. The timer is
     fired when it runs out of time.
-    
+
     Parameters
     ----------
     interval : number
         The interval of the timer in seconds.
     oneshot : bool
         Whether the timer should do a single shot, or run continuously.
-    
+
     """
 
     def __init__(self, interval=1.0, oneshot=True):
@@ -374,8 +368,7 @@ class Timer(Signal):
 
     @Property
     def interval():
-        """ Set/get the timer's interval in seconds.
-        """
+        """Set/get the timer's interval in seconds."""
 
         def fget(self):
             return self._interval
@@ -391,7 +384,7 @@ class Timer(Signal):
 
     @Property
     def oneshot():
-        """ Set/get whether this is a oneshot timer. If not is runs
+        """Set/get whether this is a oneshot timer. If not is runs
         continuously.
         """
 
@@ -405,16 +398,15 @@ class Timer(Signal):
 
     @property
     def running(self):
-        """ Get whether the timer is running.
-        """
+        """Get whether the timer is running."""
         return self._timeout > 0
 
     def start(self, interval=None, oneshot=None):
-        """ start(interval=None, oneshot=None)
-        
+        """start(interval=None, oneshot=None)
+
         Start the timer. If interval or oneshot are not given,
         their current values are used.
-        
+
         """
         # set properties?
         if interval is not None:
@@ -427,16 +419,16 @@ class Timer(Signal):
         theTimerThread.add(self)
 
     def stop(self):
-        """ stop()
-        
+        """stop()
+
         Stop the timer from running.
-        
+
         """
         theTimerThread.discard(self)
         self._timeout = 0
 
     def _on_timeout(self):
-        """ Method to call when the timer finishes. Called from
+        """Method to call when the timer finishes. Called from
         event-loop-thread.
         """
 
@@ -456,17 +448,17 @@ class Timer(Signal):
 
 
 class YotonApplication(object):
-    """ YotonApplication
-    
+    """YotonApplication
+
     Represents the yoton application and contains functions for
     the event system. Multiple instances can be created, they will
     all operate on the same event queue and share attributes
     (because these are on the class, not on the instance).
-    
+
     One instance of this class is always accesible via yoton.app.
     For convenience, several of its methods are also accessible
     directly from the yoton module namespace.
-    
+
     """
 
     # Event queues
@@ -484,10 +476,10 @@ class YotonApplication(object):
     _embedding_callback2 = None  # Used in post_event
 
     def call_later(self, func, timeout=0.0, *args, **kwargs):
-        """ call_later(func, timeout=0.0, *args, **kwargs)
-        
+        """call_later(func, timeout=0.0, *args, **kwargs)
+
         Call the given function after the specified timeout.
-        
+
         Parameters
         ----------
         func : callable
@@ -500,7 +492,7 @@ class YotonApplication(object):
             The arguments to call func with.
         kwargs: keyword arguments.
             The keyword arguments to call func with.
-        
+
         """
 
         # Wrap the object in an event
@@ -515,10 +507,10 @@ class YotonApplication(object):
             self.post_event(event)
 
     def post_event(self, event):
-        """ post_event(events)
-        
+        """post_event(events)
+
         Post an event to the event queue.
-        
+
         """
         YotonApplication._event_queue.push(event)
         #
@@ -527,11 +519,11 @@ class YotonApplication(object):
             YotonApplication._embedding_callback1()
 
     def post_event_asap(self, event):
-        """ post_event_asap(event)
-        
+        """post_event_asap(event)
+
         Post an event to the event queue. Handle as soon as possible;
         putting it in front of the queue.
-        
+
         """
         YotonApplication._event_queue.insert(event)
         #
@@ -540,25 +532,25 @@ class YotonApplication(object):
             YotonApplication._embedding_callback1()
 
     def post_event_later(self, event, delay):
-        """ post_event_later(event, delay)
-        
+        """post_event_later(event, delay)
+
         Post an event to the event queue, but with a certain delay.
-        
+
         """
         event._timeout = time.time() + delay
         theTimerThread.add(event)
         # Calls post_event in due time
 
     def process_events(self, block=False):
-        """ process_events(block=False)
-        
+        """process_events(block=False)
+
         Process all yoton events currently in the queue.
         This function should be called periodically
         in order to keep the yoton event system running.
-        
+
         block can be False (no blocking), True (block), or a float
         blocking for maximally 'block' seconds.
-        
+
         """
         # Reset callback for the embedding event loop
         YotonApplication._embedding_callback2 = YotonApplication._embedding_callback1
@@ -573,11 +565,11 @@ class YotonApplication(object):
             pass
 
     def start_event_loop(self):
-        """ start_event_loop()
-        
+        """start_event_loop()
+
         Enter an event loop that keeps calling yoton.process_events().
         The event loop can be stopped using stop_event_loop().
-        
+
         """
 
         # Dont go if we are in an event loop
@@ -597,10 +589,10 @@ class YotonApplication(object):
             YotonApplication._in_event_loop = False
 
     def stop_event_loop(self):
-        """ stop_event_loop()
-        
+        """stop_event_loop()
+
         Stops the event loop if it is running.
-        
+
         """
         if not YotonApplication._stop_event_loop:
             # Signal stop
@@ -613,16 +605,16 @@ class YotonApplication(object):
             self.post_event(Event(dummy))
 
     def embed_event_loop(self, callback):
-        """ embed_event_loop(callback)
-        
+        """embed_event_loop(callback)
+
         Embed the yoton event loop in another event loop. The given callback
         is called whenever a new yoton event is created. The callback
         should create an event in the other event-loop, which should
         lead to a call to the process_events() method. The given callback
         should be thread safe.
-        
+
         Use None as an argument to disable the embedding.
-        
+
         """
         YotonApplication._embedding_callback1 = callback
         YotonApplication._embedding_callback2 = callback
